@@ -105,7 +105,7 @@ class EtsySession:
         if headers is None:
             headers = {"x-api-key": self.CLIENT_KEY}
 
-        res = self.__async_oauth2_session.request(url=url, method=method, headers=headers, *args, **kwargs)
+        res = await self.__async_oauth2_session.request(url=url, method=method, headers=headers, *args, **kwargs)
             
         json = await res.json()
         
